# sung

Music data access. Mainly sources from spotify and wikipedia.

To install:	```pip install sung```


# Examples

```python
>>> from sung import search_tracks
>>> search_tracks('Autumn leaves', limit=3, genre='jazz')  # doctest: +ELLIPSIS
```